/*======================================================== */
/*
Supporting Stata Code for Quantile Regression Results (Figures 1-3) of:
IV QUANTILE REGRESSION FOR GROUP-LEVEL TREATMENTS
CHETVERIKOV, LARSEN, AND PALMER (2015)
-----------------------------------------------------------
See CLP_example_stata_code\CLP_generic_stata_code.do for sample code that can be adapted to any application. 
** PLEASE READ "APPLICATION READ ME FILE.txt" FIRST FOR DESCRIPTION **
** See Autor, Dorn, and Hanson (2013) for additional details about sample construction, etc. **
-----------------------------------------------------------
Table of Contents
-----------------------------------------------------------

SECTION 0: 	Options, Directory, and Local Macros
SECTION 1: 	Run and Save ADH Mean Regressions
SECTION 2: 	Run and Save Quantile Regressions
SECTION 3: 	Merge Quantile Regression Results with ADH Mean Results and Output Figures 1-3
	
-----------------------------------------------------------
*/
/*======================================================== */


//SECTION 0: 	Options, Directory, and Local Macros


/*======================================================== */

** Install parmest if it is not already loaded into your Stata 
*cap ssc install parmest

** Set your directory where the data is stored **
* cd

** SET OPTIONS AND NAME TEMPFILES **
clear all
set memory 500m
set more off

tempfile reg_lnwkwage_all reg_lnwkwage_m reg_lnwkwage_f reg_lnwkwage_c ///
	reg_lnwkwage_c_m reg_lnwkwage_c_f reg_lnwkwage_nc reg_lnwkwage_nc_m ///
	reg_lnwkwage_nc_f reg_lnwkwage_mfg reg_lnwkwage_mfg_c ///
	reg_lnwkwage_mfg_nc reg_lnwkwage_nmfg reg_lnwkwage_nmfg_c ///
	reg_lnwkwage_nmfg_nc ADH_regression_results ///
	orireg_all orireg_m orireg_f orireg_c orireg_c_m ///
	orireg_c_f orireg_nc orireg_nc_m orireg_nc_f orireg_mfg orireg_mfg_c ///
	orireg_mfg_nc orireg_nmfg orireg_nmfg_c orireg_nmfg_nc ///

/*======================================================== */


//SECTION 1: 	Run and Save ADH Mean Regressions


/*======================================================== */
  
//Regenerate Table 6 & 7 of ADH paper, using downloaded IPUMS data
//Refer to do-file: czone_analysis_ipw_final.do

//Original regressions from ADH
use CLP_regression_data, clear

foreach class in all m f c c_m c_f nc nc_m nc_f mfg mfg_c mfg_nc nmfg nmfg_c nmfg_nc {
	preserve
	qui ivregress 2sls adh_d_avg_lnwkwage (d_tradeusch_pw=d_tradeotch_pw_lag) l_shind_manuf_cbp l_sh_popedu_c l_sh_popfborn l_sh_empl_f l_sh_routine33 l_task_outsource reg* t2 [aw=timepwt48] if class=="`class'", cluster(statefip)
	qui parmest,fast ids(ori_`class') saving(`orireg_`class'')
	restore
}

//Appending
use `orireg_all', clear
keep if parm=="d_tradeusch_pw"
save `ADH_regression_results', replace
foreach class in m f c c_m c_f nc nc_m nc_f mfg mfg_c mfg_nc nmfg nmfg_c nmfg_nc {
	use `orireg_`class'', clear
	keep if parm=="d_tradeusch_pw"
	append using `ADH_regression_results'
	save `ADH_regression_results', replace
}

//Save ADH regression results for use in Figures 1-3
save `ADH_regression_results', replace


/*======================================================== */


//SECTION 2: 	Run and Save Quantile Regressions


/*======================================================== */

//Run Panel A Table 6 with different quantiles data; differentiate all levels
//Refer to do-file: czone_analysis_ipw_final.do

use CLP_regression_data, clear

**Loop over the suffixes (sample specifications)**
foreach class in all m f c c_m c_f nc nc_m nc_f mfg mfg_c mfg_nc nmfg nmfg_c nmfg_nc {
	preserve
	qui ivregress 2sls d_p5_lnwkwage (d_tradeusch_pw=d_tradeotch_pw_lag) l_shind_manuf_cbp l_sh_popedu_c l_sh_popfborn l_sh_empl_f l_sh_routine33 l_task_outsource reg* t2 [aw=timepwt48] if class=="`class'", cluster(statefip)
	qui parmest,fast idn(5) saving(`reg_lnwkwage_`class'')
	restore
}

//Then all other quantiles, loop through and append regression results
forvalues q=10 15 to 95 {

	tempfile tfall
	
	**All workers first**
	preserve
	qui ivregress 2sls d_p`q'_lnwkwage (d_tradeusch_pw=d_tradeotch_pw_lag) l_shind_manuf_cbp l_sh_popedu_c l_sh_popfborn l_sh_empl_f l_sh_routine33 l_task_outsource reg* t2 [aw=timepwt48] if class=="all", cluster(statefip)
	qui parmest,fast idn(`q') saving(`tfall', replace)
	restore
	preserve
	drop _all
	append using `reg_lnwkwage_all' `tfall'
	qui save `reg_lnwkwage_all', replace
	restore
	
	**All other regressions, loop over the suffixes**
	foreach class in m f c c_m c_f nc nc_m nc_f mfg mfg_c mfg_nc nmfg nmfg_c nmfg_nc {
			tempfile tf`class'
			preserve
			qui ivregress 2sls d_p`q'_lnwkwage (d_tradeusch_pw=d_tradeotch_pw_lag) l_shind_manuf_cbp l_sh_popedu_c l_sh_popfborn l_sh_empl_f l_sh_routine33 l_task_outsource reg* t2 [aw=timepwt48] if class=="`class'", cluster(statefip)
			qui parmest,fast idn(`q') saving(`tf`class'', replace)
			restore
			preserve
			drop _all
			append using `reg_lnwkwage_`class'' `tf`class''
			qui save `reg_lnwkwage_`class'', replace
			restore
	}
}

/*======================================================== */


//SECTION 3: 	Merge Quantile Regression Results with ADH Mean Results and Output Figures 1-3


/*======================================================== */
  
//Run Panel A of ADH Table 6 with different quantiles data; differentiate all levels
//Refer to do-file: czone_analysis_ipw_final.do

//Identify suffixes (sample specifications) of interest:
*foreach class in all m f c c_m c_f nc nc_m nc_f mfg mfg_c mfg_nc nmfg nmfg_c nmfg_nc {
foreach class in all m f {
	**keep parameter estimates**
	use `reg_lnwkwage_`class'', clear
	qui keep if parm=="d_tradeusch_pw"
	qui keep idnum estimate min95 max95 stderr
	qui save `reg_lnwkwage_`class'', replace
}

local i=0 // counter for figure number

//Identify suffixes (sample specifications) of interest:
*foreach class in all f m c c_m c_f nc nc_m nc_f mfg mfg_c mfg_nc nmfg nmfg_c nmfg_nc {
foreach class in all f m {
	//Append using regression mean data
	local i=`i'+1
	use ADH_regression_results, clear
	keep parmseq idstr estimate max95 min95
	keep if idstr=="ori_`class'"
	reshape wide estimate max95 min95, i(parmseq) j(idstr) string
	drop parmseq
	rename estimateori_`class' original_estimate
	rename max95ori_`class' max95_original
	rename min95ori_`class' min95_original

	expand 19

	merge using `reg_lnwkwage_`class''
	assert _merge==3
	drop _merge
	
	replace idnum=idnum/100 // Quantiles
	
	//Plotting
	twoway (line original_estimate idnum, pstyle(p3)) (rline max95_original min95_original idnum,pstyle(p4) lpattern(shortdash)) ///
		(connected estimate idnum, pstyle(p1)) (rline max95 min95 idnum, lpattern(dash) pstyle(p2)) ///
		, xtitle("Quantile") xlabel(0.1(0.1)0.90, format(%9.1f)) ylabel(-3(.5)1,gmax gmin) yscale(range(-3 1.16422)) name(`class',replace) saving(quantileplot_`class', replace) ///
		legend(label(3 "Point Estimate") label(4 "95% Confidence Interval") label(1 "ADH Estimate") label(2 "ADH 95% Confidence Interval") order(3 4 1 2))
	graph export color_fig`i'.png, replace width(2400)
	graph export color_fig`i'.eps, replace

	* black and white versions
	twoway (line original_estimate idnum, pstyle(p3)) (rline max95_original min95_original idnum,pstyle(p2) lpattern(shortdash)) ///
		(connected estimate idnum, pstyle(p1)) (rline max95 min95 idnum, lpattern(dash) pstyle(p4)) ///
		, graphregion(fcolor(white)) scheme(s2mono) xtitle("Quantile") xlabel(0.1(0.1)0.90, format(%9.1f)) ylabel(-3(.5)1, gmin gmax)  yscale(range(-3 1.16422)) name(`class',replace) ///
		legend(label(3 "Point Estimate") label(4 "95% Confidence Interval") label(1 "ADH Estimate") label(2 "ADH 95% Confidence Interval") order(3 4 1 2))
	graph export blackwhite_fig`i'.png, replace width(2400)
	graph export blackwhite_fig`i'.eps, replace
	
	save CLP_regresults_`class', replace	
}

