/*======================================================== */
/*
Supporting Stata Code for Data Preparation (Figures 1-3) of:
IV QUANTILE REGRESSION FOR GROUP-LEVEL TREATMENTS
CHETVERIKOV, LARSEN, AND PALMER (2015)
-----------------------------------------------------------
See CLP_example_stata_code\CLP_generic_stata_code.do for sample code that can be adapted to any application. 
** PLEASE READ "APPLICATION READ ME FILE.txt" FIRST FOR DESCRIPTION **
** See Autor, Dorn, and Hanson (2013) for additional details about sample construction, etc. **
-----------------------------------------------------------
Table of Contents
-----------------------------------------------------------
SECTION 0:	Options, Directory, and Local Macros
SECTION 1: 	Generate Samples
	STEP 1: 	Create ln wage file for 1990/2000
	STEP 2: 	Create top incomes file for 2006/07/08
	STEP 3: 	Create ln wage file for 2006/07/08
SECTION 2: 	Calculate Quantiles by Group for Various Subsamples
SECTION 3: 	Merge and Prepare Files for Regression Output

-----------------------------------------------------------
*/
/*======================================================== */


//SECTION 0: Options, Directory, and Local Macros


/*======================================================== */

** Install parmest if it is not already loaded into your Stata 
*cap ssc install parmest

** Set your directory where the data is stored **
* cd

** SET OPTIONS AND NAME TEMPFILES **
clear all
set memory 500m
set more off

tempfile lswt1990 lswt2000 lswt2006 lswt2007 lswt2008 1990data 2000data ///
	lnwkwage_19902000b temp acs060708_topincwage_pooled lnwkwage_060708b ///
	lnwkwage_all 1990lnwkwage 2000lnwkwage 2007lnwkwage lnwkwage quantile_data

/*======================================================== */


//SECTION 1: Generate Samples


/*======================================================== */
//STEP 1: Create ln wage file for 1990/2000
/*======================================================== */

//Regenerate ADH sample for 1990 & 2000 with IPUMS microdata

//1990 & 2000 data
//See "APPLICATION READ ME FILE.txt" file for a description of how to download microdata from http://usa.ipums.org
use 1990_2000ipums, clear

//Drop unwanted workers: Before lswt

**age 16-64 keep**
drop if age<16 | age>64
**keep if working in the year preceding**
keep if workedyr==3
**drop if residents of institutional group quarters**
drop if gqtyped>=100 & gqtyped<=499
**drop if unpaid family worker**
drop if classwkrd==29

//Generate labor weight count
**Subfile:logmeanwage_lswtgen**
**Generate education dummies**
**I deduce this part from the naming of the code**

generate edu_lths=(educd<=26) //Middle School or lower
generate edu_hsch=(educd<=64 & educd>=30) //High School
generate edu_scoll=(educd<=100 & educd>=65) //Some college education
generate edu_coll=(educd>=101) //Finish College degree

** Labor supply weight - calculate where possible, impute by occupation 
** for those with missing hours or weeks 
foreach yr in "1990" "2000" {
	preserve
	keep if year==`yr'
	gen lswt=perwt*(uhrswork/35)*(wkswork1/50)
	replace lswt=. if lswt==0

	gen edcat= 1*edu_lths + 2*edu_hsch + 3*edu_scoll + 4*edu_coll
	assert edcat!=. & edcat>=1 & edcat<=4
	egen mnwt=sum(lswt),by(occ1990 edcat)
	egen temp=sum(perwt*(lswt!=.)),by(occ1990 edcat)
	replace mnwt=mnwt/temp

	gen byte impute=lswt==.
	replace lswt=perwt*mnwt if lswt==.

	* One more level of imputation if needed
	drop temp mnwt
	egen mnwt=sum(lswt),by(edcat)
	egen temp=sum(perwt*(lswt!=.)),by(edcat)
	replace mnwt=mnwt/temp
	assert mnwt!=.
	replace lswt=perwt*mnwt if lswt==.
	//tab impute, summ(lswt)
	drop mnwt temp
	save `lswt`yr'', replace
	restore
}

drop _all
append using `lswt1990' `lswt2000'

//Drop unwanted samples: After lswt
gen byte earnsamp=1
replace earnsamp=0 if classwkrd>=10 & classwkrd<=14
replace earnsamp=0 if uhrswork==0 | uhrswork==.
replace earnsamp=0 if wkswork1==0 | wkswork1==.
replace earnsamp=0 if incwage==0 | incwage==999999
tab earnsamp [aw=lswt]

//Classification dummies
**Dummies for Manufacturing sector: indicator ind1990**
generate manufacture=0
replace manufacture=1 if (ind1990>=100 & ind1990<=392)
**Dummies for college education: indicator educ**
generate college=0
replace college=1 if (educd>=65)
**Dummies for sex**
generate male=1
replace male=0 if (sex==2)

//Adjust top-coded wages and weekly wages, ceiling source: original subfile
generate hrwage=0
**1990**
replace incwage=1.5*140000 if incwage>=140000 & year==1990
scalar MAXWG1990=(1.5*140000/(35*50))
scalar list MAXWG1990
replace hrwage=incwag/(uhrswork*wkswork1) if year==1990
replace hrwage=MAXWG1990 if hrwage>MAXWG1990 & hrwage!=. & year==1990
replace hrwage=. if earnsamp==0 & year==1990
**2000**
replace incwage=1.5*175000 if incwage>=175000 & year==2000
scalar MAXWG2000=(1.5*175000/(35*50))
scalar list MAXWG2000
replace hrwage=incwag/(uhrswork*wkswork1) if year==2000
replace hrwage=MAXWG2000 if hrwage>MAXWG2000 & hrwage!=. & year==2000
replace hrwage=. if earnsamp==0 & year==2000

//Winsorize below first-percentile wages
generate wkwage=0
**1990**
sum hrwage [aw=lswt] if year==1990, detail
scalar MINWG1990= r(p1)
scalar list MINWG1990
assert MINWG1990>0
replace hrwage=MINWG1990 if hrwage<MINWG1990 & hrwage!=. & year==1990
replace wkwage=hrwage*uhrswork if year==1990
sum wkwage [aw=lswt] if year==1990, detail
sum wkwage if uhrswork>=35 & year==1990 [aw=lswt], detail
**2000**
sum hrwage [aw=lswt] if year==2000, detail
scalar MINWG2000= r(p1)
scalar list MINWG2000
assert MINWG2000>0
replace hrwage=MINWG2000 if hrwage<MINWG2000 & hrwage!=. & year==2000
replace wkwage=hrwage*uhrswork if year==2000
sum wkwage [aw=lswt], detail
sum wkwage if uhrswork>=35 & year==2000 [aw=lswt], detail

//Weekly wage generate
//inflate wage to 2007 using Persinal Consumption Expenditure index, David Dorn's Original Data
** Inflation adjustment ($2007) **
** Based on PCE index (www.gpoaccess.gov/eop/2009/B3.xls) **
** 1989 - 76.972 **
** 1999 - 97.575 **
** 2007 - 117.659 **
generate real_wkwage=0
replace real_wkwage=wkwage*(117.659/76.972) if wkwage!=. & year==1990
replace real_wkwage=wkwage*(117.659/97.575) if wkwage!=. & year==2000

//Output raw file
**keep relevant vars to speed things up**
keep perwt lswt puma year incwage manufacture college male real_wkwage wkwage statefip
**log weekly wages, times 100 to unit log points**
generate ln_wkwage=100*ln(real_wkwage)

//Crosswork to CZs
**add statefip for puma**
tostring puma, replace
replace puma="0"+puma if length(puma)==3
**drop the puma code 77777, no reference**
drop if length(puma)==5
assert length(puma)==4
tostring statefip, generate(stateref)
replace stateref="0"+stateref if length(stateref)==1
assert length(stateref)==2
replace puma=stateref+puma
drop stateref
assert length(puma)==6
destring puma, replace

**1990**
preserve
keep if year==1990
joinby puma using 1990czcrosswalk, unmatched(both) _merge(merge90)
assert merge90==3
drop merge90
generate weight=afactor*lswt
save `1990data', replace
restore
**2000**
keep if year==2000
joinby puma using 2000czcrosswalk, unmatched(both) _merge(merge00)
assert merge00==3
drop merge00
generate weight=afactor*lswt
save `2000data', replace
**append**
drop _all
append using `1990data' `2000data'

save `lnwkwage_19902000b', replace


/*======================================================== */
//STEP 2: Create top incomes file for 2006/07/08 (SECTION 1)
/*======================================================== */
//Generate topincwage for 060708data
//Top wage according to statefip using ipums explanations on inctopwage

** This is from creating the relevant IPUMS extract **
** see "IPUMS extract codes.txt" **
use 060708ipums_pooled, clear

**modify as wkswork1 is missing**
generate wkswork1=0
replace wkswork1=7 if wkswork2==1 
replace wkswork1=20 if wkswork2==2
replace wkswork1=33 if wkswork2==3
replace wkswork1=43.5 if wkswork2==4
replace wkswork1=48.5 if wkswork2==5 
replace wkswork1=51 if wkswork2==6 

//Drop unwanted workers: Before lswt
**age 16-64 keep**
drop if age<16 | age>64
**keep if working in the year preceding**
keep if workedyr==3
**drop if residents of institutional group quarters**
drop if gqtyped>=100 & gqtyped<=499
**drop if unpaid family worker**
drop if classwkrd==29

//Generate labor weight count
**Generate education dummies**

generate edu_lths=(educd<=26) //Middle School or lower
generate edu_hsch=(educd<=64 & educd>=30) //High School
generate edu_scoll=(educd<=100 & educd>=65) //Some college education
generate edu_coll=(educd>=101) //Finish College degree

** Labor supply weight - calculate where possible, impute by occupation 
** for those with missing hours or weeks 
foreach yr in "2006" "2007" "2008" {
	preserve
	keep if multyear==`yr'
	gen lswt=perwt*(uhrswork/35)*(wkswork1/50)
	replace lswt=. if lswt==0

	gen edcat= 1*edu_lths + 2*edu_hsch + 3*edu_scoll + 4*edu_coll
	assert edcat!=. & edcat>=1 & edcat<=4
	egen mnwt=sum(lswt),by(occ1990 edcat)
	egen temp=sum(perwt*(lswt!=.)),by(occ1990 edcat)
	replace mnwt=mnwt/temp

	gen byte impute=lswt==.
	replace lswt=perwt*mnwt if lswt==.
	//tab impute, summ(lswt)

	** One more level of imputation if needed **
	//count if lswt==.
	drop temp mnwt
	egen mnwt=sum(lswt),by(edcat)
	egen temp=sum(perwt*(lswt!=.)),by(edcat)
	replace mnwt=mnwt/temp
	assert mnwt!=.
	replace lswt=perwt*mnwt if lswt==.
	//tab impute, summ(lswt)
	drop mnwt temp
	save `lswt`yr'', replace
	restore
}

drop _all
append using `lswt2006' `lswt2007' `lswt2008'

//Drop unwanted workers: After lswt
gen byte earnsamp=1
replace earnsamp=0 if classwkrd>=10 & classwkrd<=14
replace earnsamp=0 if uhrswork==0 | uhrswork==.
replace earnsamp=0 if wkswork1==0 | wkswork1==.
replace earnsamp=0 if incwage==0 | incwage==999999
tab earnsamp [aw=lswt]
drop if earnsamp==0

//Top wage: 99.5 percentile within each state
keep lswt incwage statefip multyear 

generate topincwage=0
forvalues st=1/56 {
	foreach yr in 2006 2007 2008 {
		_pctile incwage [aw=lswt] if (multyear==`yr' & statefip==`st'), p(99.5)
		return list
		qui replace topincwage=r(r1) if (multyear==`yr' & statefip==`st')
	}
}
collapse (mean) topincwage, by(statefip multyear)

save `acs060708_topincwage_pooled', replace


/*======================================================== */
//STEP 3: Create ln wage file for 2006/07/08 (SECTION 1)
/*======================================================== */
//060708 data
use 060708ipums_pooled, clear


**modify as wkswork1 is missing**
generate WKSWORK1=0
replace WKSWORK1=7 if wkswork2==1 
replace WKSWORK1=20 if wkswork2==2
replace WKSWORK1=33 if wkswork2==3
replace WKSWORK1=43.5 if wkswork2==4
replace WKSWORK1=48.5 if wkswork2==5 
replace WKSWORK1=51 if wkswork2==6 

//Drop unwanted workers: Before lswt
**age 16-64 keep**
drop if age<16 | age>64
**keep if worked in the year preceding**
keep if workedyr==3
**drop if residents of institutional group quarters**
drop if gqtyped>=100 & gqtyped<=499
**drop if unpaid family worker**
drop if classwkrd==29

//Generate labor weight count
**Generate education dummies**

generate edu_lths=(educd<=26) //Middle School or lower
generate edu_hsch=(educd<=64 & educd>=30) //High School
generate edu_scoll=(educd<=100 & educd>=65) //Some college education
generate edu_coll=(educd>=101) //Finish College degree

** Labor supply weight - calculate where possible, impute by occupation 
** for those with missing hours or weeks 
foreach yr in "2006" "2007" "2008" {
	preserve
	keep if multyear==`yr'
	gen lswt=perwt*(uhrswork/35)*(WKSWORK1/50)
	replace lswt=. if lswt==0
	//summ lswt perwt
	//count if lswt==.

	gen edcat= 1*edu_lths + 2*edu_hsch + 3*edu_scoll + 4*edu_coll
	assert edcat!=. & edcat>=1 & edcat<=4
	egen mnwt=sum(lswt),by(occ1990 edcat)
	egen temp=sum(perwt*(lswt!=.)),by(occ1990 edcat)
	replace mnwt=mnwt/temp
	//summ mnwt
	//count if mnwt==.

	gen byte impute=lswt==.
	replace lswt=perwt*mnwt if lswt==.
	//tab impute, summ(lswt)

	** One more level of imputation if needed **
	//count if lswt==.
	drop temp mnwt
	egen mnwt=sum(lswt),by(edcat)
	egen temp=sum(perwt*(lswt!=.)),by(edcat)
	replace mnwt=mnwt/temp
	assert mnwt!=.
	replace lswt=perwt*mnwt if lswt==.
	//tab impute, summ(lswt)
	drop mnwt temp
	save `lswt`yr'', replace
	restore
}

drop _all
append using `lswt2006' `lswt2007' `lswt2008'

//Drop unwanted sample: After lswt
**drop if self-employed**
**drop if weeks, wage, hours are missing**
**if those equal 0 also count as missing**

gen byte earnsamp=1
replace earnsamp=0 if classwkrd>=10 & classwkrd<=14
replace earnsamp=0 if uhrswork==0 | uhrswork==.
replace earnsamp=0 if WKSWORK1==0 | WKSWORK1==.
replace earnsamp=0 if incwage==0 | incwage==999999
tab earnsamp [aw=lswt]

//Classification dummies
**Dummies for Manufacturing sector: indicator ind1990**
generate manufacture=0
replace manufacture=1 if (ind1990>=100 & ind1990<=392)
**Dummies for college education: indicator educ**
generate college=0
replace college=1 if (educd>=65)
**Dummies for gender**
generate male=1
replace male=0 if (sex==2)

//Top and bottom wages adjustment
** Top and bottom code wages
** NOTE: the 2006-2008 ACS uses state and year-specific top-codes
save `temp', replace

**Top Wages**
use `acs060708_topincwage_pooled', clear
merge 1:m multyear statefip using `temp'
assert _merge==3
drop _merge

replace incwage=1.5*topincwage if incwage>=topincwage
generate MAXWG=(1.5*topincwage/(35*50))
generate hrwage=incwage/(uhrswork*WKSWORK1)
replace hrwage=MAXWG if hrwage>MAXWG & hrwage!=.
replace hrwage=. if earnsamp==0

**Bottom Wages**
foreach yr in 2006 2007 2008 {
	sum hrwage [aw=lswt] if multyear==`yr', detail
	scalar MINWG`yr'= r(p1)
	scalar list MINWG`yr'
	assert MINWG`yr'>0
	replace hrwage=MINWG`yr' if hrwage<MINWG`yr' & hrwage!=. & multyear==`yr'
}

//Weekly wage generated
gen wkwage=hrwage*uhrswork

//Inflation adjust
** I use separate data for 2006/2007/2008 data so no CPI readjustment **
** Inflation adjustment ($2007) **
** Based on PCE index (www.gpoaccess.gov/eop/2009/B3.xls) **
** 1989 - 76.972 **
** 1999 - 97.575 **
** 2006 - 114.675 **
** 2007 - 117.659 **
** 2008 - 122.318 (Avg. of second and third quarter) **
generate real_wkwage=0

** Adjustment 1: Undo the CPI-U adjustment of the original ACS data **
replace real_wkwage=wkwage*(201.6/215.303) if wkwage!=. & multyear==2006
replace real_wkwage=wkwage*(207.342/215.303) if wkwage!=. & multyear==2007

** Adjustment 2: PCE adjustment **
replace real_wkwage=wkwage*(117.659/114.675) if wkwage!=. & multyear==2006
replace real_wkwage=wkwage*(117.659/122.318) if wkwage!=. & multyear==2008

//Output raw file
**keep relevant vars to speed things up**
keep perwt lswt puma multyear incwage manufacture college male real_wkwage wkwage statefip
**log weekly wages, times 100 to unit log points**
generate ln_wkwage=100*ln(real_wkwage)

//Crosswork to CZs
**add statefip for puma**
tostring puma, replace
replace puma="0"+puma if length(puma)==3
**drop the puma code 77777, no reference**
drop if length(puma)==5
assert length(puma)==4
tostring statefip, generate(stateref)
replace stateref="0"+stateref if length(stateref)==1
assert length(stateref)==2
replace puma=stateref+puma
drop stateref
assert length(puma)==6
destring puma, replace
joinby puma using 2000czcrosswalk, unmatched(both) _merge(merge07)
//assert merge07==3
//3 pumas in using files but not master file:221905,221801,221802, not able to be identified since those are coded 77777 in ipums
//czone 3300 was then disturbed
drop merge07
generate weight=afactor*lswt

save `lnwkwage_060708b', replace

/*======================================================== */


// SECTION 2: Calculate Quantiles by Group for Various Subsamples


/*======================================================== */

//Run ADH Panel A Table 6 spec with different quantiles data; differentiate all levels
//Refer to do-file: czone_analysis_ipw_final.do

//Append
use `lnwkwage_19902000b', clear
keep afactor weight czone ln_wkwage year manufacture male college
save `lnwkwage_all', replace

use `lnwkwage_060708b', clear
cap drop year

generate year=2007
keep afactor weight czone ln_wkwage year manufacture male college
append using `lnwkwage_all'
save `lnwkwage_all', replace

//Collapse, taking into consideration afactor and perwt.
//First take mean at puma level, then merge to czone level
//Do this separately for Table 6, 7 breaking with mfg and gender and education level
//Loop over for all quantiles from 5, 10, ....95

forvalues q=5 10 to 95 {

	**Split into different years of census then collapse**
	**Note for each one: 741 czones exists**

	**1990**
	use if year==1990 using `lnwkwage_all', clear
	**collapse 0: Table 6, all workers**
	preserve
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_1990
	qui save `1990lnwkwage', replace
	restore
	**collapse 1: Table 6, male, all educ**
	preserve
	qui keep if male==1
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_1990_m
	qui merge 1:1 czone using `1990lnwkwage', nogenerate
	qui save `1990lnwkwage', replace
	restore
	**collapse 2: Table 6, female, all educ**
	preserve
	qui keep if male==0
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_1990_f
	qui merge 1:1 czone using `1990lnwkwage', nogenerate
	qui save `1990lnwkwage', replace
	restore
	**collapse 3: Table 6, male, college educ**
	preserve
	qui keep if (male==1 & college==1)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_1990_c_m
	qui merge 1:1 czone using `1990lnwkwage', nogenerate
	qui save `1990lnwkwage', replace
	restore
	**collapse 4: Table 6, female, college educ**
	preserve
	qui keep if (male==0 & college==1)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_1990_c_f
	qui merge 1:1 czone using `1990lnwkwage', nogenerate
	qui save `1990lnwkwage', replace
	restore
	**collapse 5: Table 6, male, no college educ**
	preserve
	qui keep if (male==1 & college==0)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_1990_nc_m
	qui merge 1:1 czone using `1990lnwkwage', nogenerate
	qui save `1990lnwkwage', replace
	restore
	**collapse 6: Table 6, female, no college educ**
	preserve
	qui keep if (male==0 & college==0)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_1990_nc_f
	qui merge 1:1 czone using `1990lnwkwage', nogenerate
	qui save `1990lnwkwage', replace
	restore
	**collapse 7: Table 6, all gender, college educ**
	preserve
	qui keep if college==1
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_1990_c
	qui merge 1:1 czone using `1990lnwkwage', nogenerate
	qui save `1990lnwkwage', replace
	restore
	**collapse 8: Table 6, all gender, no college educ**
	preserve
	qui keep if college==0
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_1990_nc
	qui merge 1:1 czone using `1990lnwkwage', nogenerate
	qui save `1990lnwkwage', replace
	restore
	**collapse 9: Table 7, manufacturing, all educ**
	preserve
	qui keep if manufacture==1
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_1990_mfg
	qui merge 1:1 czone using `1990lnwkwage', nogenerate
	qui save `1990lnwkwage', replace
	restore
	**collapse 10: Table 7, no manufacturing, all educ**
	preserve
	qui keep if manufacture==0
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_1990_nmfg
	qui merge 1:1 czone using `1990lnwkwage', nogenerate
	qui save `1990lnwkwage', replace
	restore
	**collapse 11: Table 7, manufacturing, college educ**
	preserve
	qui keep if (manufacture==1 & college==1)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_1990_mfg_c
	qui merge 1:1 czone using `1990lnwkwage', nogenerate
	qui save `1990lnwkwage', replace
	restore
	**collapse 12: Table 7, manufacturing, no college educ**
	preserve
	qui keep if (manufacture==1 & college==0)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_1990_mfg_nc
	qui merge 1:1 czone using `1990lnwkwage', nogenerate
	qui save `1990lnwkwage', replace
	restore
	**collapse 13: Table 7, no manufacturing, college educ**
	preserve
	qui keep if (manufacture==0 & college==1)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_1990_nmfg_c
	qui merge 1:1 czone using `1990lnwkwage', nogenerate
	qui save `1990lnwkwage', replace
	restore
	**collapse 14: Table 7, no manufacturing, no college educ**
	qui keep if (manufacture==0 & college==0)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_1990_nmfg_nc
	qui merge 1:1 czone using `1990lnwkwage', nogenerate
	qui save `1990lnwkwage', replace
	
	**2000**
	use if year==2000 using `lnwkwage_all', clear
	**collapse 0: Table 6, all workers**
	preserve
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2000
	qui save `2000lnwkwage', replace
	restore
	**collapse 1: Table 6, male, all educ**
	preserve
	qui keep if male==1
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2000_m
	qui merge 1:1 czone using `2000lnwkwage', nogenerate
	qui save `2000lnwkwage', replace
	restore
	**collapse 2: Table 6, female, all educ**
	preserve
	qui keep if male==0
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2000_f
	qui merge 1:1 czone using `2000lnwkwage', nogenerate
	qui save `2000lnwkwage', replace
	restore
	**collapse 3: Table 6, male, college educ**
	preserve
	qui keep if (male==1 & college==1)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2000_c_m
	qui merge 1:1 czone using `2000lnwkwage', nogenerate
	qui save `2000lnwkwage', replace
	restore
	**collapse 4: Table 6, female, college educ**
	preserve
	qui keep if (male==0 & college==1)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2000_c_f
	qui merge 1:1 czone using `2000lnwkwage', nogenerate
	qui save `2000lnwkwage', replace
	restore
	**collapse 5: Table 6, male, no college educ**
	preserve
	qui keep if (male==1 & college==0)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2000_nc_m
	qui merge 1:1 czone using `2000lnwkwage', nogenerate
	qui save `2000lnwkwage', replace
	restore
	**collapse 6: Table 6, female, no college educ**
	preserve
	qui keep if (male==0 & college==0)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2000_nc_f
	qui merge 1:1 czone using `2000lnwkwage', nogenerate
	qui save `2000lnwkwage', replace
	restore
	**collapse 7: Table 6, all gender, college educ**
	preserve
	qui keep if college==1
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2000_c
	qui merge 1:1 czone using `2000lnwkwage', nogenerate
	qui save `2000lnwkwage', replace
	restore
	**collapse 8: Table 6, all gender, no college educ**
	preserve
	qui keep if college==0
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2000_nc
	qui merge 1:1 czone using `2000lnwkwage', nogenerate
	qui save `2000lnwkwage', replace
	restore
	**collapse 9: Table 7, manufacturing, all educ**
	preserve
	qui keep if manufacture==1
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2000_mfg
	qui merge 1:1 czone using `2000lnwkwage', nogenerate
	qui save `2000lnwkwage', replace
	restore
	**collapse 10: Table 7, no manufacturing, all educ**
	preserve
	qui keep if manufacture==0
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2000_nmfg
	qui merge 1:1 czone using `2000lnwkwage', nogenerate
	qui save `2000lnwkwage', replace
	restore
	**collapse 11: Table 7, manufacturing, college educ**
	preserve
	qui keep if (manufacture==1 & college==1)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2000_mfg_c
	qui merge 1:1 czone using `2000lnwkwage', nogenerate
	qui save `2000lnwkwage', replace
	restore
	**collapse 12: Table 7, manufacturing, no college educ**
	preserve
	qui keep if (manufacture==1 & college==0)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2000_mfg_nc
	qui merge 1:1 czone using `2000lnwkwage', nogenerate
	qui save `2000lnwkwage', replace
	restore
	**collapse 13: Table 7, no manufacturing, college educ**
	preserve
	qui keep if (manufacture==0 & college==1)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2000_nmfg_c
	qui merge 1:1 czone using `2000lnwkwage', nogenerate
	qui save `2000lnwkwage', replace
	restore
	**collapse 14: Table 7, no manufacturing, no college educ**
	qui keep if (manufacture==0 & college==0)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2000_nmfg_nc
	qui merge 1:1 czone using `2000lnwkwage', nogenerate
	qui save `2000lnwkwage', replace

	**2007**
	use if year==2007 using `lnwkwage_all', clear
	**collapse 0: Table 6, all workers**
	preserve
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2007
	qui save `2007lnwkwage', replace
	restore
	**collapse 1: Table 6, male, all educ**
	preserve
	qui keep if male==1
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2007_m
	qui merge 1:1 czone using `2007lnwkwage', nogenerate
	qui save `2007lnwkwage', replace
	restore
	**collapse 2: Table 6, female, all educ**
	preserve
	qui keep if male==0
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2007_f
	qui merge 1:1 czone using `2007lnwkwage', nogenerate
	qui save `2007lnwkwage', replace
	restore
	**collapse 3: Table 6, male, college educ**
	preserve
	qui keep if (male==1 & college==1)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2007_c_m
	qui merge 1:1 czone using `2007lnwkwage', nogenerate
	qui save `2007lnwkwage', replace
	restore
	**collapse 4: Table 6, female, college educ**
	preserve
	qui keep if (male==0 & college==1)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2007_c_f
	qui merge 1:1 czone using `2007lnwkwage', nogenerate
	qui save `2007lnwkwage', replace
	restore
	**collapse 5: Table 6, male, no college educ**
	preserve
	qui keep if (male==1 & college==0)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2007_nc_m
	qui merge 1:1 czone using `2007lnwkwage', nogenerate
	qui save `2007lnwkwage', replace
	restore
	**collapse 6: Table 6, female, no college educ**
	preserve
	qui keep if (male==0 & college==0)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2007_nc_f
	qui merge 1:1 czone using `2007lnwkwage', nogenerate
	qui save `2007lnwkwage', replace
	restore
	**collapse 7: Table 6, all gender, college educ**
	preserve
	qui keep if college==1
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2007_c
	qui merge 1:1 czone using `2007lnwkwage', nogenerate
	qui save `2007lnwkwage', replace
	restore
	**collapse 8: Table 6, all gender, no college educ**
	preserve
	qui keep if college==0
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2007_nc
	qui merge 1:1 czone using `2007lnwkwage', nogenerate
	qui save `2007lnwkwage', replace
	restore
	**collapse 9: Table 7, manufacturing, all educ**
	preserve
	qui keep if manufacture==1
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2007_mfg
	qui merge 1:1 czone using `2007lnwkwage', nogenerate
	qui save `2007lnwkwage', replace
	restore
	**collapse 10: Table 7, no manufacturing, all educ**
	preserve
	qui keep if manufacture==0
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2007_nmfg
	qui merge 1:1 czone using `2007lnwkwage', nogenerate
	qui save `2007lnwkwage', replace
	restore
	**collapse 11: Table 7, manufacturing, college educ**
	preserve
	qui keep if (manufacture==1 & college==1)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2007_mfg_c
	qui merge 1:1 czone using `2007lnwkwage', nogenerate
	qui save `2007lnwkwage', replace
	restore
	**collapse 12: Table 7, manufacturing, no college educ**
	preserve
	qui keep if (manufacture==1 & college==0)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2007_mfg_nc
	qui merge 1:1 czone using `2007lnwkwage', nogenerate
	qui save `2007lnwkwage', replace
	restore
	**collapse 13: Table 7, no manufacturing, college educ**
	preserve
	qui keep if (manufacture==0 & college==1)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2007_nmfg_c
	qui merge 1:1 czone using `2007lnwkwage', nogenerate
	qui save `2007lnwkwage', replace
	restore
	**collapse 14: Table 7, no manufacturing, no college educ**
	qui keep if (manufacture==0 & college==0)
	qui collapse (p`q') ln_wkwage [aw=weight], by(czone)
	rename ln_wkwage p`q'_ln_wkwage_2007_nmfg_nc
	qui merge 1:1 czone using `2007lnwkwage', nogenerate
	qui save `2007lnwkwage', replace

	//Merge and calculate the difference
	//Total number of Czones: 741
	**merge**
	use `1990lnwkwage', clear
	qui merge 1:1 czone using `2000lnwkwage'
	assert _merge==3
	drop _merge
	qui merge 1:1 czone using `2007lnwkwage'
	//assert _merge==3
	drop _merge
	//Save the percentile output as a dataset
	reshape long p`q'_ln_wkwage_ , i(czone) j(yearclass) string
	gen year = substr(yearclass,1,4)
	destring year, replace
	gen class = substr(yearclass,6,.)
	replace class="all" if class==""
	drop yearclass
	tempfile p`q'_ln_wkwage_data
	save `p`q'_ln_wkwage_data', replace

}

//This will merge and save the inputs to the IV quantile regressions in one dataset
forvalues q=5 10 to 95 {
	if `q' == 5 {
	use `p`q'_ln_wkwage_data', replace
	save `quantile_data', replace
	continue
	}
drop _all
use `quantile_data', replace
qui merge 1:1 czone year class using `p`q'_ln_wkwage_data'
qui keep if _merge==3
drop _merge
save `quantile_data', replace
}

**generate difference to use in regressions**
use `quantile_data', clear
qui reshape wide p**_ln_wkwage_ , i(czone class) j(year)

forvalues q=5 10 to 95 {
	**2000-2007 times 10/7 factor**
	qui generate d_p`q'_lnwkwage1990=p`q'_ln_wkwage_2000-p`q'_ln_wkwage_1990
	qui generate d_p`q'_lnwkwage2000=(p`q'_ln_wkwage_2007-p`q'_ln_wkwage_2000)*10/7
}

**reshape in order to merge instruments**
reshape long 	d_p5_lnwkwage d_p10_lnwkwage d_p15_lnwkwage d_p20_lnwkwage ///
		d_p25_lnwkwage d_p30_lnwkwage d_p35_lnwkwage d_p40_lnwkwage ///
		d_p45_lnwkwage d_p50_lnwkwage d_p55_lnwkwage d_p60_lnwkwage ///
		d_p65_lnwkwage d_p70_lnwkwage d_p75_lnwkwage d_p80_lnwkwage ///
		d_p85_lnwkwage d_p90_lnwkwage d_p95_lnwkwage , i(czone class) j(year)

/*======================================================== */


// SECTION 3: Merge and Prepare Files for Regression Output


/*======================================================== */

rename year yr
preserve
//Prepare workfile from ADH to merge onto CLP quantile data
use workfile_china.dta, clear
keep 	d_avg_lnwkwage d_avg_lnwkwage_c d_avg_lnwkwage_nc d_avg_lnwkwage_m ///
	d_avg_lnwkwage_f d_avg_lnwkwage_c_m d_avg_lnwkwage_c_f d_avg_lnwkwage_nc_m ///
	d_avg_lnwkwage_nc_f d_avg_lnwkwage_mfg d_avg_lnwkwage_nmfg d_avg_lnwkwage_mfg_c ///
	d_avg_lnwkwage_nmfg_c d_avg_lnwkwage_mfg_nc d_avg_lnwkwage_nmfg_nc ///
	d_tradeotch_pw_lag d_tradeusch_pw l_shind_manuf_cbp ///
	l_sh_popedu_c l_sh_popfborn l_sh_empl_f l_sh_routine33 l_task_outsource ///
	reg* t2 czone yr timepwt48 statefip ///
//Rename wage variable to indicate it is directly from ADH calculations
rename d_avg_lnwkwage adh_d_avg_lnwkwage_all
foreach class in m f c nc c_m c_f nc_m nc_f mfg nmfg mfg_c nmfg_c mfg_nc nmfg_nc {
rename d_avg_lnwkwage_`class' adh_d_avg_lnwkwage_`class'
}
reshape long adh_d_avg_lnwkwage_ , i(czone yr) j(class) string
tempfile workfile_china_formerge
save `workfile_china_formerge'
restore
joinby czone yr class using `workfile_china_formerge' , unmatched(both) 
//Drop commuter zones not used by ADH in 1990/2000
keep if _merge==3 
drop _merge

rename yr year

* ADH's yr variable is actually lag year since most of their Xs are lagged
recode year (2000 = 2007) (1990 = 2000)
//quantiles in levels used to calculate diff in quantiles, no longer needed, available from running this code or by request to authors
drop p*
label var czone "Commuting Zone ID"
label var class "Subsample"
forvalues i=5(5)95 {
	label var d_p`i'_lnwkwage "Difference between t and t-1 `i'th percentile log weekly wage"
	}
label var t2 "2007 dummy"
label var timepwt48 "weights"
foreach var of varlist reg* {
	label var `var' "Region Dummies"
	}
label var adh "Difference between t and t-1 mean log weekly wage from ADH"
foreach var of varlist l_* {
	local substr=substr("`var'",3,.)
	label var `var' "Lag `substr'"
}
label var d_tradeusch_pw "Difference between t and t-1 imports per worker"
label var d_tradeotch_pw_lag "Difference between t-1 and t-2 Chinese imports to other countries per worker"

label data "Created by CLP_application-DataPrep.do. See Chetverikov, Larsen, Palmer (ECMA)"
save CLP_regression_data, replace
