function clp_simulations()
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% clp_simulations
%
% Grouped IV quantile regression simulations
%
% Denis Chetverikov, Brad Larsen, Christopher Palmer 2015
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% run simulations for various combinations of N and G
gqr_sim(25,25)
gqr_sim(25,200)
gqr_sim(200,25)
gqr_sim(200,200)

%% make main simulations table
ALL = [];
for spec = 1:3
    bias_spec = [];
    for G = [25 200]
        for N = [25 200]
            load(strcat('gqr_sim_results_N',num2str(N),'_G',num2str(G))) 
            bias_spec = [bias_spec BIAS_ALL{spec}]; 
        end
    end
    bias_spec = [bias_spec; mean(abs(bias_spec))];
    ALL = [ALL; nan*zeros(1,size(bias_spec,2)); bias_spec];
end
ALL

%% output computation time comparisons:
timesum = [];
timeavg = [];
timeratio = [];
for G = [25 200]
    for N = [25 200]
        load(strcat('gqr_sim_results_N',num2str(N),'_G',num2str(G))) 
%             disp('Seconds to do nine deciles 
        timesum = [timesum; sum([TIMES(:,2) TIMES(:,1)])]; % I reversed these in storing them (time of grouped first, joint second) 
        timeavg = [timeavg; mean([TIMES(:,2) TIMES(:,1)])]; % I reversed these in storing them (time of grouped first, joint second) 

        timeratio_vec = []; % ratio of joint to grouped time
        for tau = 1:size(TIMING,3)
            timeratio_vec = [ timeratio_vec; ...
                        TIMING(:,2,tau)./TIMING(:,1,tau)];
        end
        timeratio = [timeratio; mean(timeratio_vec)];
    end
end
timesum
timeavg
timeratio
    
end

function gqr_sim(N,G)
% N = 25; G = 25; 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% gqr_sim 
%
% Grouped quantile regression simulations
%
% Denis Chetverikov, Brad Larsen, Christopher Palmer 2015
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

stream=RandStream('mt19937ar');
RandStream.setGlobalStream(stream);

%% setup
numN = [(1:G)' N*ones(G,1)];
NG = sum(numN(:,2));

% true parameters
beta_true = @(t) sqrt(t); % beta(tau) = beta*tau
gamma_true = @(t) sqrt(t);
alpha_true = @(t) t/2;
epsilon_true = @(t,eta) t.*eta - t/2;
pi0 = 0; % first stage intercept
pi1 = 1; % first stage slope

% specifications to try:
taus = (.1:.1:.9)';
covariate = 1; 
R = 1000; % number of replications


for spec = 1:3
    if spec==1
        endog = 1;
        shock = 1; 
    elseif spec==2
        endog = 0; 
        shock = 1; 
    elseif spec==3
        endog = 0; 
        shock = 0; 
    end

    for i = 1:R
        % generate data (I try to use the convention that lower case variables
        % are either group-level (Gx1 vectors) or within group (Nx1 vectors) 
        % and upper case are NGx1 vectors)

        eta = rand(G,1); % group-level shock
        w = exp(0.25*randn(G,1));
        nu = exp(0.25*randn(G,1));
        if endog
            x = pi0 + pi1*w + eta + nu; % first-stage
        else
            x = w; % (if not doing endog case, w works for x here)
        end  

        ETA = []; X = []; ind = [];
        for g = 1:G
            ETA = [ETA; eta(g)*ones(numN(g,2),1)];
            X = [X; x(g)*ones(numN(g,2),1)];
            ind = [ind; g*ones(numN(g,2),1) (1:numN(g,2))'];
        end
        
        EPSILON = 0;
        U = rand(NG,1); % individual level heterogeneity
        if shock
            EPSILON = epsilon_true(U,ETA);
        end

        Zgamma = 0;
        Z = zeros(NG,0); % empty matrix to be space filler unless including covariates
        if covariate
            Z = exp(0.25*randn(NG,1));
            Zgamma = Z.*gamma_true(U);
        end
        
        % make a group dummies for joint estimation of coefficients on Z (just for computation comparison)
        group_dummies = kron(eye(G),ones(N,1));

        y = alpha_true(U) + X.*beta_true(U) + Zgamma + EPSILON;

        xc = [ones(G,1) x]; % x with column for constant included
        XC = [ones(size(X,1),1) X Z]; % with column for constant included

        for tau_num = 1:length(taus)
            tau = taus(tau_num); % for the tauth quantile
            params_qr = quantlsf(XC,y,tau); % abadie code

            % groupedQR
            % Step 1) Run quantile regression within each group, or just collapse if no covariates
            data_all = [ind y XC];
            if covariate
                C = zeros(G,1);
                gam_vec = zeros(G,1);
                tic; 
                for g = 1:G
                    yg = data_all(data_all(:,1)==g,3);
                    zg = data_all(data_all(:,1)==g,end);
                    zcg = [ones(length(yg),1) zg];
                    params_qr_g = quantlsf(zcg,yg,tau);
                    C(g) = params_qr_g(1);
                    gam_vec(g) = params_qr_g(2);
                end
                % Check computation time difference if we estimate all group-effects jointly
                t1 = toc;
                if i<=100 && spec==1 % only need to check timing for spec=1 (because estimating alphas would be the same in any spec) and for the first 100 replications for speed
                    tic;
                    params_qr_joint = quantlsf([group_dummies Z],y,tau);
                    t2 = toc;
                    %% this should agree: 
                    % [params_qr_joint(1:G) C]
                    time_length = [t1 t2]; % grouped, then joint
                end
            else
                C = zeros(G,1);
                for g = 1:G
                    yg = data_all(data_all(:,1)==g,3);
                    C(g) = quantile(yg,tau);
                end

            end
    
            % Step 2) 2SLS or OLS
            if endog % do 2sls:
                wc = [ones(G,1) w]; % instruments with a column for constant
                A = (wc'*wc)\(wc'*xc);
                params_grouped = ((wc*A)'*xc)\((wc*A)'*C);
            else  % do ols
                params_grouped = (xc'*xc)\(xc'*C);
            end
            if i<=100 && spec==1 
                TIMING(i,:,tau_num) = time_length;
            end
            
            RESULTS(i,:,tau_num) = [params_qr' params_grouped'];
            if ~mod(i,100) && tau_num==length(taus)
                disp(num2str([N G spec i ]))
            end
        end
    end
    RESULTS_ALL{spec} = RESULTS; 
    
    for tau_num = 1:length(taus)
        results = RESULTS(:,:,tau_num);
        mean_results = mean(results);
        % fill out a matrix with just the average betas
        BETAS(tau_num,1:2) = [mean_results(2) mean_results(end)];
        if spec==1
            TIMES(tau_num,1:2) = mean(TIMING(:,:,tau_num));
        end
    end
    BIAS_ALL{spec} = BETAS -  beta_true(taus*[1 1]);
end

save(strcat('gqr_sim_results_N',num2str(N),'_G',num2str(G)),'BIAS_ALL','taus','RESULTS_ALL','TIMES','TIMING')


end




%=========================================================================
function b = quantlsf(X,y,q)
% Calculates Quantile Regression coefficients.
% Written by Moshe Buchinski and Gary Chamberlain.
% Alberto Abadie modified line 12.

limit=100;
[N, K] = size(X);

bls = X\y;
e = y-X*bls;
e = sort(e); 
bls(1) = bls(1) + e(round(N*q));
y = y-X*bls;

labelout = [1:K];
labelin = [K+1:K+N];
c = q*ones(1,N);

ind = find(y < 0);
if length(ind)>0,
y(ind) = -y(ind);
X(ind,:) = - X(ind,:);
labelin(ind) = -labelin(ind);
c(ind) = -c(ind) + 1.0;
end

%size(X)
T = [X, y; c*X, c*y];
clear X y c;
criterion = [T(N+1,1:K), -T(N+1,1:K)];
[margcost, s] = max(criterion);
count = 0;
for i = 1:K,
  if s > K,
     s = s-K; T(1:N,s) = -T(1:N,s);
     T(N+1,s) = margcost;
     labelout(s) = -labelout(s);
  end 
  ind = find(T(1:N,s) > 0 & abs(labelin') > K);
if length(ind)>0,
  [val, loc] = sort(T(ind,K+1) ./ T(ind,s));
clear val;
  r = ind(loc(1));
  init = 1;
  while (margcost - T(r,s)) > 0 & init < length(ind),
    T(N+1,:) = T(N+1,:) - T(r,:);
    margcost = T(N+1,s);
    T(r,:) = -T(r,:);
    labelin(r) = -labelin(r);
    init = init + 1;
    r = ind(loc(init));
  end
  T(:,K+2) = ([1:(N+1)]' == r);
  T(r,:) = T(r,:)/T(r,s);
  ind = find([1:N+1] ~= r);
  T(ind,:) = T(ind,:) - (T(ind,s)/T(r,s))*T(r,:);
  T(:,s) = T(:,K+2);
  move = labelout(s);
  labelout(s) = labelin(r);
  labelin(r) = move;
end

  if i < K,
    ind = find(abs(labelout) <= K);
    criterion = [T(N+1,ind), -T(N+1,ind)];
    [margcost, loc] = max(criterion);
    if loc <= length(ind),
      s = ind(loc);
    else
      s = K + ind(loc - length(ind));
    end
    count = count + 1;
  else
    criterion = [T(N+1,1:K), (-T(N+1,1:K) - 1.0)];
    [margcost, s] = max(criterion);
    count = count + 1;
  end
end
%
while margcost > 10*eps & count <= limit,
  if s > K,
     s = s-K; T(1:N,s) = -T(1:N,s);
     T(N+1,s) = margcost;
     labelout(s) = -labelout(s);
  end 
  ind = find(T(1:N,s) > 0 & abs(labelin') > K);
  [val, loc] = sort(T(ind,K+1) ./ T(ind,s));
clear val;
  r = ind(loc(1));
  init = 1;
  while (margcost - T(r,s)) > 0 & init < length(ind),
    T(N+1,:) = T(N+1,:) - T(r,:);
    margcost = T(N+1,s);
    T(r,:) = -T(r,:);
    labelin(r) = -labelin(r);
    init = init + 1;
    r = ind(loc(init));
  end
  T(:,K+2) = ([1:(N+1)]' == r);
  T(r,:) = T(r,:)/T(r,s);
  ind = find([1:N+1] ~= r);
  T(ind,:) = T(ind,:) - (T(ind,s)/T(r,s))*T(r,:);
  T(:,s) = T(:,K+2);
  move = labelout(s);
  labelout(s) = labelin(r);
  labelin(r) = move;
  criterion = [T(N+1,1:K), (-T(N+1,1:K) - 1.0)];
  [margcost, s] = max(criterion);
  count = count + 1;
end
ind = find(abs(labelin) <= K);
blabel = labelin(ind)';
b = T(ind,K+1) .* sign(blabel);
[a, ind] = sort(abs(blabel));
b = b(ind);
b = b+bls;

end




